Coverage for /home/tribaal/workspace/django-shop/shop/urls/__init__: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/urls/__init__ : 100.00%

## 3 statements 3 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | # -*- coding: utf-8 -*- from django.conf.urls.defaults import patterns, include, url from shop.views import ShopTemplateView urlpatterns = patterns('', url(r'^$', ShopTemplateView.as_view(template_name="shop/welcome.html"), name='shop_welcome'), (r'^pay/', include('shop.payment.urls')), (r'^ship/', include('shop.shipping.urls')), (r'^orders/', include('shop.urls.order')), (r'^checkout/', include('shop.urls.checkout')), (r'^cart/', include('shop.urls.cart')), (r'^products/', include('shop.urls.catalog')), )